@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2013, Luis Pedro Coelho <luis@luispedro.org>
+# Copyright (C) 2010-2014, Luis Pedro Coelho <luis@luispedro.org>
 # vim: set ts=4 sts=4 sw=4 expandtab smartindent:
 #
 # License: MIT (see COPYING file)
@@ -101,20 +101,20 @@ def convolve1d(f, weights, axis, mode='reflect', cval=0., out=None, output=None)
     if weights.ndim != 1:
         raise ValueError('mahotas.convolve1d: only 1-D sequences allowed')
     _check_mode(mode, cval, 'convolve1d')
-    if f.flags.contiguous:
+    if f.flags.contiguous and len(weights) < f.shape[axis]:
         weights = weights.astype(np.double)
         indices = [a for a in range(f.ndim) if a != axis] + [axis]
         rindices = [indices.index(a) for a in range(f.ndim)]
         oshape = f.shape
         f = f.transpose(indices)
+        tshape = f.shape
         f = f.reshape((f.shape[0],-1))
-        f = f.transpose()
 
         out = _get_output(f, out, 'convolve1d')
         _convolve.convolve1d(f, weights, out, mode2int[mode])
-        out = out.transpose()
+        out = out.reshape(tshape)
         out = out.transpose(rindices)
-        out.reshape(oshape)
+        out = out.reshape(oshape)
         return out
     else:
         index = [None] * f.ndim
