@@ -11,14 +11,18 @@ filename = path.join(
 
 
 def skip_on(etype):
+    from functools import wraps
     def skip_on2(test):
-        try:
-            yield test
-        except e:
-            if isinstance(e, etype):
-                from nose import SkipTest
-                raise SkipTest
-            raise
+        @wraps(test)
+        def execute(*args, **kwargs):
+            try:
+                test(*args, **kwargs)
+            except Exception as e:
+                if isinstance(e, etype):
+                    from nose import SkipTest
+                    raise SkipTest
+                raise
+        return execute
     return skip_on2
 
 
@@ -40,3 +44,15 @@ def test_as_grey():
             'luispedro.jpg')
     im = mh.imread(filename, as_grey=1)
     assert im.ndim == 2
+
+@skip_on(ImportError)
+def test_matplotlibwrap():
+    filename = path.join(
+            path.dirname(__file__),
+            '..',
+            'demos',
+            'data',
+            'lena.jpg')
+    import mahotas.io.matplotlibwrap
+    im = mahotas.io.matplotlibwrap.imread(filename)
+    assert im.shape == (512,512,3)
